@@ -3,19 +3,8 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 from zope.interface import implements  # pylint: disable=unused-import
@@ -78,7 +67,7 @@ class FocusRect(QGraphicsRectItem, StrMixin):
             self.refresh()
 
     @afterQueuedAnimations
-    def refresh(self, dummyDeferredResult=None):
+    def refresh(self, unusedDeferredResult=None):
         """show/hide on correct position after queued animations end"""
         board = self.board
         if not isAlive(board) or not isAlive(self):
@@ -95,7 +84,7 @@ class FocusRect(QGraphicsRectItem, StrMixin):
             self.setPos(board.focusTile.pos)
         game = Internal.scene.game
         self.setVisible(board.isVisible() and bool(board.focusTile)
-                        and board.isEnabled() and board.hasFocus and bool(game) and not game.autoPlay)
+                        and board.isEnabled() and board.hasLogicalFocus and bool(game) and not game.autoPlay)
 
 
     def __str__(self):
@@ -147,7 +136,7 @@ class GameScene(SceneWithFocusRect):
         Internal.scene = self
         self.mainWindow = parent
         self._game = None
-        super(GameScene, self).__init__()
+        super().__init__()
 
         self.scoreTable = None
         self.explainView = None
@@ -179,7 +168,7 @@ class GameScene(SceneWithFocusRect):
         self.mainWindow.adjustMainView()
 
     @afterQueuedAnimations
-    def showShadowsChanged(self, deferredResult, dummyOldValue, dummyNewValue): # pylint: disable=unused-argument
+    def showShadowsChanged(self, deferredResult, unusedOldValue, unusedNewValue): # pylint: disable=unused-argument
         """if the wanted shadow direction changed, apply that change now"""
         for uiTile in self.graphicsTileItems():
             uiTile.setClippingFlags()
@@ -275,11 +264,11 @@ class GameScene(SceneWithFocusRect):
                     sBar.removeItem(idx)
 
     def graphicsTileItems(self):
-        """returns all UITile in the scene"""
+        """return all UITile in the scene"""
         return (x for x in self.items() if isinstance(x, UITile))
 
     def nonTiles(self):
-        """returns all other items in the scene"""
+        """return all other items in the scene"""
         return (x for x in self.items() if not isinstance(x, UITile))
 
     def removeTiles(self):
@@ -300,7 +289,7 @@ class PlayingScene(GameScene):
         self.__startingGame = True
         self._clientDialog = None
 
-        super(PlayingScene, self).__init__(parent)
+        super().__init__(parent)
 
     @GameScene.game.setter
     def game(self, value):  # pylint: disable=arguments-differ
@@ -332,7 +321,7 @@ class PlayingScene(GameScene):
             self._clientDialog.hide()
         self._clientDialog = value
 
-    def resizeEvent(self, dummyEvent):
+    def resizeEvent(self, unusedEvent):
         """main window changed size"""
         if self.clientDialog:
             self.clientDialog.placeInField()
@@ -370,14 +359,13 @@ class PlayingScene(GameScene):
             return result
         if not self.game:
             return succeed(True)
-        autoPlaying = self.mainWindow.actionAutoPlay.isChecked()
         self.mainWindow.actionAutoPlay.setChecked(False)
         if self.game.finished():
             self.game = None
             return succeed(True)
-        else:
-            return QuestionYesNo(i18n("Do you really want to abort this game?"), always=True).addCallback(
-                gotAnswer, autoPlaying)
+        autoPlaying = self.mainWindow.actionAutoPlay.isChecked()
+        return QuestionYesNo(i18n("Do you really want to abort this game?"), always=True).addCallback(
+            gotAnswer, autoPlaying)
 
     def keyPressEvent(self, event):
         """if we have a clientDialog, pass event to it"""
@@ -432,10 +420,8 @@ class PlayingScene(GameScene):
         game = self.game
         mainWindow = self.mainWindow
         if not game:
-            connections = list(
-                x.connection for x in HumanClient.humanClients if x.connection)
-            title = ', '.join('{name}/{url}'.format(name=x.username, url=x.url)
-                              for x in connections)
+            connections = [x.connection for x in HumanClient.humanClients if x.connection]
+            title = ', '.join('{name}/{url}'.format(name=x.username, url=x.url) for x in connections)
             if title:
                 decorateWindow(mainWindow, title)
         else:
@@ -468,8 +454,8 @@ class ScoringScene(GameScene):
 
     def __init__(self, parent=None):
         self.scoringDialog = None
-        super(ScoringScene, self).__init__(parent)
-        self.selectorBoard.hasFocus = True
+        super().__init__(parent)
+        self.selectorBoard.hasLogicalFocus = True
 
     @GameScene.game.setter
     def game(self, value):  # pylint: disable=arguments-differ
@@ -508,11 +494,10 @@ class ScoringScene(GameScene):
             logDebug('ScoringScene.abort invoked')
         if not self.game:
             return succeed(True)
-        elif self.game.finished():
+        if self.game.finished():
             self.game = None
             return succeed(True)
-        else:
-            return QuestionYesNo(i18n("Do you really want to abort this game?"), always=True).addCallback(answered)
+        return QuestionYesNo(i18n("Do you really want to abort this game?"), always=True).addCallback(answered)
 
     def __moveTile(self, uiTile, wind, toConcealed):
         """the user pressed a wind letter or X for center, wanting to move a uiTile there"""
@@ -548,15 +533,15 @@ class ScoringScene(GameScene):
             return True
         if key == Qt.Key_Tab and self.game:
             tabItems = [self.selectorBoard]
-            tabItems.extend(
-                list(p.handBoard for p in self.game.players if p.handBoard.uiTiles))
+            tabItems.extend(p.handBoard for p in self.game.players if p.handBoard.uiTiles)
             tabItems.append(tabItems[0])
             currentBoard = uiTile.board
             currIdx = 0
             while tabItems[currIdx] != currentBoard and currIdx < len(tabItems) - 2:
                 currIdx += 1
-            tabItems[currIdx + 1].hasFocus = True
+            tabItems[currIdx + 1].hasLogicalFocus = True
             return True
+        return False
 
     def keyPressEvent(self, event):
         """navigate in the selectorboard"""
@@ -604,6 +589,7 @@ class ScoringScene(GameScene):
         if self.scoringDialog:
             # is None while ScoringGame is created
             return self.scoringDialog.computeLastTile()
+        return None
 
     def computeLastMeld(self):
         """compile hand info into a string as needed by the scoring engine"""
